ToSqlAny

Trait ToSqlAny 

pub trait ToSqlAny:
    ToSql
    + Any
    + Sync { }
A trait to mark types that can be converted to a ToSql type and also implement Any and Sync. This trait is used for the parameters of the queries.

Implementors

Source

impl<T: ToSql + Any + Sync> ToSqlAny for T